==> chromium_88.0.4324.96.orig.tar.xz: chromium-88.0.4324.96/chrome/browser/resources/new_tab_page/modules/dummy/module.js <==
// Copyright 2020 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

import 'chrome://resources/cr_elements/cr_grid/cr_grid.js';

import '../../img.js';
import '../../strings.m.js';

import {loadTimeData} from 'chrome://resources/js/load_time_data.m.js';
import {html, PolymerElement} from 'chrome://resources/polymer/v3_0/polymer/polymer_bundled.min.js';

import {ModuleDescriptor} from '../module_descriptor.js';
import {FooProxy} from './foo_proxy.js';

/**
 * @fileoverview A dummy module, which serves as an example and a helper to
 * build out the NTP module framework.
 */

class DummyModuleElement extends PolymerElement {
  static get is() {
    return 'ntp-dummy-module';
  }

  static get template() {
    return html`{__html_template__}`;
  }

  static get properties() {
    return {
      /** @type {!Array<!foo.mojom.FooDataItem>} */
      tiles: Array,
    };
  }

  constructor() {
    super();
    this.initializeData_();
  }

  /** @private */
  async initializeData_() {
    const tileData = await FooProxy.getInstance().handler.getData();
    this.tiles = tileData.data;
  }
}

customElements.define(DummyModuleElement.is, DummyModuleElement);

/** @type {!ModuleDescriptor} */
export const dummyDescriptor = new ModuleDescriptor(
    /*id=*/ 'dummy',
    /*heightPx=*/ 260, () => Promise.resolve({
      element: new DummyModuleElement(),
      title: loadTimeData.getString('modulesDummyTitle'),
    }));

/** @type {!ModuleDescriptor} */
export const dummyDescriptor2 = new ModuleDescriptor(
    /*id=*/ 'dummy2',
    /*heightPx=*/ 260, () => Promise.resolve({
      element: new DummyModuleElement(),
      title: loadTimeData.getString('modulesDummy2Title'),
    }));

==> chromium_89.0.4389.114.orig.tar.xz: chromium-89.0.4389.114/chrome/browser/resources/new_tab_page/modules/dummy/module.js <==
// Copyright 2020 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

import 'chrome://resources/cr_elements/cr_grid/cr_grid.js';

import '../../img.js';
import '../../strings.m.js';
import '../module_header.js';

import {loadTimeData} from 'chrome://resources/js/load_time_data.m.js';
import {html, PolymerElement} from 'chrome://resources/polymer/v3_0/polymer/polymer_bundled.min.js';

import {ModuleDescriptor} from '../module_descriptor.js';
import {FooProxy} from './foo_proxy.js';

/**
 * @fileoverview A dummy module, which serves as an example and a helper to
 * build out the NTP module framework.
 */

class DummyModuleElement extends PolymerElement {
  static get is() {
    return 'ntp-dummy-module';
  }

  static get template() {
    return html`{__html_template__}`;
  }

  static get properties() {
    return {
      /** @type {!Array<!foo.mojom.FooDataItem>} */
      tiles: Array,

      /** @type {!string} */
      title: String,
    };
  }

  constructor() {
    super();
    this.initializeData_();
  }

  /** @private */
  async initializeData_() {
    const tileData = await FooProxy.getInstance().handler.getData();
    this.tiles = tileData.data;
  }
}

customElements.define(DummyModuleElement.is, DummyModuleElement);

/**
 * @param {!string} titleId
 * @return {!DummyModuleElement}
 */
function createDummyElement(titleId) {
  const element = new DummyModuleElement();
  element.title = loadTimeData.getString(titleId);
  return element;
}

/** @type {!ModuleDescriptor} */
export const dummyDescriptor = new ModuleDescriptor(
    /*id=*/ 'dummy',
    /*heightPx=*/ 314,
    () => Promise.resolve(createDummyElement('modulesDummyTitle')));

/** @type {!ModuleDescriptor} */
export const dummyDescriptor2 = new ModuleDescriptor(
    /*id=*/ 'dummy2',
    /*heightPx=*/ 314,
    () => Promise.resolve(createDummyElement('modulesDummy2Title')));
